==> ng-describe-0.4.0.tgz: package/test/karma.conf.js <==
// Karma configuration
// Generated on Tue Oct 14 2014 14:19:39 GMT-0400 (EDT)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['mocha'],


    // list of files / patterns to load in the browser
    files: [
        '../node_modules/check-types/src/check-types.js',
        '../node_modules/check-more-types/check-more-types.js',
        '../node_modules/lazy-ass/index.js',
        '../node_modules/angular/angular.js',
        '../node_modules/angular-mocks/angular-mocks.js',
        '../node_modules/lazy-ass-helpful/lazy-ass-helpful-browser.js',
        '../node_modules/lazy-ass-helpful/lazy-ass-helpful-bdd.js',
        '../ng-describe.js',
        './*-spec.js'
    ],


    // list of files to exclude
    exclude: [
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
        '../ng-describe.js': ['coverage']
    },


    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['nested', 'coverage'],

    coverageReporter: {
        type : 'lcov',
        dir : 'coverage/'
    },


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['PhantomJS'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: true,

    plugins: [
        'karma-nested-reporter',
        'karma-mocha',
        'karma-phantomjs-launcher',
        'karma-coverage'
    ]
  });
};

==> ng-describe-0.8.2.tgz: package/test/karma.conf.js <==
// Karma configuration
// Generated on Tue Oct 14 2014 14:19:39 GMT-0400 (EDT)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['mocha'],


    // list of files / patterns to load in the browser
    files: [
        '../node_modules/check-types/src/check-types.js',
        '../node_modules/check-more-types/check-more-types.js',
        '../node_modules/lazy-ass/index.js',
        '../node_modules/angular/angular.js',
        '../node_modules/angular-mocks/angular-mocks.js',
        '../node_modules/lazy-ass-helpful/lazy-ass-helpful-browser.js',
        '../node_modules/lazy-ass-helpful/lazy-ass-helpful-bdd.js',
        '../ng-describe.js',
        './*-spec.js'
    ],


    // list of files to exclude
    exclude: [
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
        '../ng-describe.js': []
    },


    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['nested', 'coverage'],

    coverageReporter: {
        type : 'lcov',
        dir : 'coverage/'
    },


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['PhantomJS'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: true,

    plugins: [
        'karma-nested-reporter',
        'karma-mocha',
        'karma-phantomjs-launcher',
        'karma-chrome-launcher',
        'karma-coverage'
    ]
  });
};
